/* ide-pygobject-script.h
 *
 * Copyright (C) 2015 Garrett Regier <garrettregier@gmail.com>
 *
 * This file is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This file is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef IDE_PYGOBJECT_SCRIPT_H
#define IDE_PYGOBJECT_SCRIPT_H

#include "scripting/ide-script.h"

G_BEGIN_DECLS

#define IDE_TYPE_PYGOBJECT_SCRIPT (ide_pygobject_script_get_type())

G_DECLARE_FINAL_TYPE (IdePyGObjectScript, ide_pygobject_script, IDE, PYGOBJECT_SCRIPT, IdeScript)

G_END_DECLS

#endif /* IDE_PYGOBJECT_SCRIPT_H */
